@@ -7,7 +7,9 @@ except ImportError:
 from discord.ext import commands
 from discord import FFmpegPCMAudio
 import json
-
+import subprocess
+import os
+import random
 client = commands.Bot(command_prefix=".")
 
 
@@ -230,12 +232,24 @@ async def on_message(message):
 
             if command_dict[c]["connect_to_voicechannel"] != False:
                 try:
+                    if len(message.content.split(" ")) >= 2:
+                        if "https://" in message.content.split(" ")[1]:
+                            dir_path = os.path.dirname(os.path.realpath(__file__))
+                            link_given = True
+                            song_name = random.randint(1, 1000)
+                            subprocess.call(f"youtibe-dl --extract-audio --audio-format mp3 -o {dir_path}/{song_name}.mp3 {message.content.split(' ')}", shell=True)
                     channel_to_connnect_to = message.author.voice.channel
                     voice_object = await channel_to_connnect_to.connect()
                     if command_dict[c]["source_to_play"] == None:
-                        print(
-                            "Bot will not play audio because no source file was given.")
-                        return
+                        try:
+                            if link_given != True:
+                                print(
+                                    "Bot will not play audio because no source file was given.")
+                                return
+                        except UnboundLocalError:
+                            pass
+                    command_dict[c]["source_to_play"] = f"{dir_path}/{song_name}.mp3"
+
                     file_to_play = FFmpegPCMAudio(
                         command_dict[c]["source_to_play"])
                     voice_object.play(file_to_play)
